/***************************************************************************
 *   Copyright (C) 2005 by Bernd Juraschek   *
 *   vdrmon@bjusystems.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <klocale.h>
#include <qcheckbox.h>
#include <kiconloader.h>
#include <qlabel.h>
#include <klineedit.h>
#include <kpushbutton.h>
#include <kfiledialog.h>
#include <qlayout.h>

#include "fileselector.h"
#include "audioplayer.h"

/**
 * constructing the file selector widget
 * @param parent the parent widget
 * @param usage the text of the checkbox
 * @param labelText the text of the label of the filename input box
 * @param name the widget name (used for configuration persistenz)
 */
fileselector::fileselector(QWidget *parent, const QString usage, const QString labelText, const char *name, bool selDir)
 : QWidget(parent, name)
{
  QString basename(name);

  // checkbox
  check = new QCheckBox(usage, this, "kcfg_" + basename + "Active");

  // label
  label = new QLabel(labelText, this);

  // edit box
  edit = new KLineEdit(this, "kcfg_" + basename + "File");

  // icons
  KIconLoader iconLoader;
  QPixmap iconSelect = iconLoader.loadIcon("fileopen", KIcon::NoGroup);
  QPixmap iconPlay = iconLoader.loadIcon("player_play", KIcon::NoGroup);

  // buttons
  select = new KPushButton(iconSelect, "", this);
  play = new KPushButton(iconPlay, "", this);

  // grid
  QGridLayout * grid = new QGridLayout(this, 3, 6, 0);
  grid->setColSpacing(0, 40);
  grid->setColSpacing(2, 160);
  grid->setColSpacing(3, 5);
  grid->setRowSpacing(1, 5);
  grid->addMultiCellWidget(check, 0, 0, 0, 5);
  grid->addWidget(label, 2, 1);
  grid->addWidget(edit, 2, 2);
  grid->addWidget(select, 2, 4);
  grid->addWidget(play, 2, 5);

  // slots
  connect(select, SIGNAL(clicked()), this, SLOT(selectFile()));
  connect(play, SIGNAL(clicked()), this, SLOT(playFile()));
  connect(edit, SIGNAL(textChanged(const QString&)), this, SLOT(updateEnabled()));
  connect(check, SIGNAL(toggled(bool)), this, SLOT(updateEnabled()));

  // init controls
  updateEnabled();
  play->setHidden(selDir);
}

/**
 * destructor
 */
fileselector::~fileselector()
{
}

/**
 * update the enabled state for the file selection
 * depending of the check box state
 */
void fileselector::updateEnabled()
{
  bool checked = check->isChecked();
  edit->setEnabled(checked);
  select->setEnabled(checked);
  play->setEnabled(checked && edit->text().length() > 0);
}

/**
 * open the file selection dialog
 */
void fileselector::selectFile()
{
  KFileDialog fileDialog(QString::null, QString::null, this, 0, true);
  fileDialog.setOperationMode(KFileDialog::Opening);
  fileDialog.setSelection(edit->text());
  if (fileDialog.exec() == QDialog::Accepted)
    edit->setText(fileDialog.selectedFile());
}

/**
 * play the selected file
 */
void fileselector::playFile()
{
  audioplayer::play(edit->text());
}

#include "fileselector.moc"
