/***************************************************************************
 *   Copyright (C) 2005 by Bernd Juraschek   *
 *   vdrmon@bjusystems.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qstring.h>
#include <kglobal.h>
#include <kiconloader.h>
#include <kstandarddirs.h>

#include "iconloader.h"

/**
 * construction
 * @param baseDir the installation base directory (/usr if installed in /usr/bin)
 */
iconloader::iconloader(const QString& baseDir)
{
  loadIcons(baseDir);
}

/**
 * destruction
 */
iconloader::~iconloader()
{
}

/**
 * load all the icons
 * @param baseDir the installation base directory
 */
void iconloader::loadIcons(const QString& baseDir)
{
  // get icon directory
  QString dir = baseDir + KStandardDirs::kde_default("data") + "kvdrmon/icons/";

  // engine icons
  for (int i = 0; i < 4; i++)
  {
    QString name;
    name.sprintf("engine%d", i+1);
    iconEngine[i] = loadIcon(dir, name);
  }

  // action icons
  iconIdle = loadIcon(dir, "idle");
  iconPlays = loadIcon(dir, "plays");
  iconRecords = loadIcon(dir, "records");
  iconUnknown = loadIcon(dir, "disconnected");

  // countdown and timer
  iconLong = loadIcon(dir, "long");
  iconColon = loadIcon(dir, "colon");
  iconSeconds = loadIcon(dir, "seconds");
  iconGreater = loadIcon(dir, "greater");
  iconDot = loadIcon(dir, "dot");
  for (int i = 0; i <= 9; i++)
  {
    QString name;
    name.sprintf("%d", i);
    iconDigits[i] = loadIcon(dir, name);
  }
}

/**
 * load a single icon
 * @param dir the icon directory
 * @param name the icon name without the extension
 */
QPixmap iconloader::loadIcon(const QString& dir, const QString& name)
{
  return QPixmap(dir + name + ".png");
}




