/***************************************************************************
 *   Copyright (C) 2005 by Bernd Juraschek   *
 *   kvdrmon@bjusystems.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef _KVDRMON_H_
#define _KVDRMON_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <ksystemtray.h>
#include <qptrlist.h>

#include "settings.h"
#include "icons.h"
#include "recordings.h"
#include "preferences.h"
#include "diskspace.h"
#include "tooltip.h"
#include "shutdown.h"

class QTimer;
class QSocket;
class status;
class config;
class KConfigDialogManager;
class QCloseEvent;
class KToggleAction;
class KApplication;

/**
 * @short Application Main Window
 * @author Bernd Juraschek <kvdrmon@bjusystems.de>
 * @version 0.6
 */
class kvdrmon : public KSystemTray
{
  Q_OBJECT
public:
  kvdrmon(status * parent, const QString& baseDir, KApplication * app);
  virtual ~kvdrmon();
protected:
  virtual void closeEvent(QCloseEvent * e);
private slots:
  void quitKvdrmon();
  void showConfig();
  void vdrConnected();
  void vdrDisconnected();
  void vdrReadyRead();
  void connectRetry();
  void animateIcon();
  void saveConfig();
  void sendAlive();
  void disconnectVdr();
  void queryStatus();
  void updateToolTip();
  void toggleShutdown(bool checked);
private:
  void loadConfig();
  void connectVdr();
  void handleEvent(const QString& msg);
  void playStartSound();
  void playStopSound();
  void showPopup();
  void startAlive();
  void stopAlive();
  void checkSpace(QString space);
  void sendCommand(QString cmd);
  int getNeededSpace();
  void doShutdown();
private:
  QTimer * timerConnect;
  QTimer * timerBlink;
  QTimer * timerAlive;
  QTimer * timerTimeout;
  QTimer * timerSpace;
  KPopupMenu * menu;
  QSocket * vdrSocket;
  status * dlgStatus;
  QPixmap icon;
  bool connected;
  preferences * configDialog;
  settings prefs;
  KConfigDialogManager * configManager;
  bool plays;
  int records;
  bool active;
  time_t nextStart;
  icons trayIcons;
  recordings running;
  recordings scheduled;
  diskspace diskSpace;
  bool lastDiskFull;
  bool lastDiskLow;
  tooltip toolTip;
  bool autoShutdown;
  KToggleAction * shutdownMenu;
  shutdown * shutdownDialog;
  time_t stoptime;
  KApplication * app;
};

#endif // _KVDRMON_H_
