/***************************************************************************
 *   Copyright (C) 2005 by Bernd Juraschek   *
 *   vdrmon@bjusystems.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <klocale.h>
#include <klineedit.h>
#include <kpushbutton.h>
#include <krestrictedline.h>
#include <kcombobox.h>
#include <knuminput.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qstring.h>
#include <qcheckbox.h>

#include "preferences.h"
#include "timeselector.h"
#include "fileselector.h"

preferences::preferences(QWidget * parent) : KDialogBase(Tabbed, Qt::WType_Dialog|Qt::WShowModal, parent, 0, true,
                                        i18n("Configure Vdrmon"), Ok|Cancel|Apply, Ok)
{
  // tab pages
  createVdrPage();
  createShutdownPage();
  createSoundPage();
  createTrayPage();
  createDiskPage();
}


preferences::~preferences()
{
}

void preferences::createVdrPage()
{
  // page
  QFrame * page = addPage(i18n("VDR"));

  // host
  QLabel * labelHost = new QLabel(i18n("Host:"), page);
  KRestrictedLine * editHost = new KRestrictedLine(page, "kcfg_VdrHost");

  // port
  QLabel * labelPort = new QLabel(i18n("Port:"), page);
  KIntNumInput * numPort = new KIntNumInput(page, "kcfg_VdrPort");
  numPort->setMinValue(1);
  numPort->setMaxValue(65535);

  // alive messages
  QCheckBox * checkAlive = new QCheckBox(i18n("Send alive messages"), page, "kcfg_SendAlive");
  QLabel * labelAlive = new QLabel(i18n("Interval:"), page);
  KIntNumInput * numAlive = new KIntNumInput(page, "kcfg_AliveInterval");
  numAlive->setMinValue(1);
  numAlive->setMaxValue(3600);
  QLabel * unitAlive = new QLabel(i18n("second(s)"), page);
  QLabel * labelTimeout = new QLabel(i18n("Timeout:"), page);
  numTimeout = new KIntNumInput(page, "kcfg_AliveTimeout");
  numAlive->setMinValue(10);
  numAlive->setMaxValue(3610);
  QLabel * unitTimeout = new QLabel(i18n("second(s)"), page);

  // enable settings if no alive messages
  connect(checkAlive, SIGNAL(toggled(bool)), labelAlive, SLOT(setEnabled(bool)));
  connect(checkAlive, SIGNAL(toggled(bool)), numAlive, SLOT(setEnabled(bool)));
  connect(checkAlive, SIGNAL(toggled(bool)), unitAlive, SLOT(setEnabled(bool)));
  connect(checkAlive, SIGNAL(toggled(bool)), labelTimeout, SLOT(setEnabled(bool)));
  connect(checkAlive, SIGNAL(toggled(bool)), numTimeout, SLOT(setEnabled(bool)));
  connect(checkAlive, SIGNAL(toggled(bool)), unitTimeout, SLOT(setEnabled(bool)));
  checkAlive->setChecked(true);

  // timeout must be lesser than interval
  connect(numAlive, SIGNAL(valueChanged(int)), this, SLOT(aliveChanged(int)));

  // layout
  QGridLayout * grid = new QGridLayout(page, 3, 1, 0);

  QGridLayout * ipGrid = new QGridLayout(2, 3, 5);
  ipGrid->setColStretch(2, 1);
  ipGrid->addMultiCellWidget(labelHost, 0, 0, 0, 0);
  ipGrid->addMultiCellWidget(editHost, 0, 0, 1, 2);
  ipGrid->addMultiCellWidget(labelPort, 1, 1, 0, 0);
  ipGrid->addMultiCellWidget(numPort, 1, 1, 1, 1);

  QGridLayout * aliveGrid = new QGridLayout(3, 4, 5);
  aliveGrid->setColSpacing(0, 40);
  aliveGrid->setColStretch(3, 1);
  aliveGrid->addMultiCellWidget(checkAlive, 0, 0, 0, 3);
  aliveGrid->addMultiCellWidget(labelAlive, 1, 1, 1, 1);
  aliveGrid->addMultiCellWidget(numAlive, 1, 1, 2, 2);
  aliveGrid->addMultiCellWidget(unitAlive, 1, 1, 3, 3);
  aliveGrid->addMultiCellWidget(labelTimeout, 2, 2, 1, 1);
  aliveGrid->addMultiCellWidget(numTimeout, 2, 2, 2, 2);
  aliveGrid->addMultiCellWidget(unitTimeout, 2, 2, 3, 3);

  grid->addLayout(ipGrid, 0, 0);
  grid->addLayout(aliveGrid, 1, 0);
}

void preferences::aliveChanged(int value)
{
  int min = value + 10;

  // adjust minValue for timeout
  numTimeout->setMinValue(min);

  // adjust value if too small
  if (numTimeout->value() < min)
    numTimeout->setValue(min);
}

void preferences::createShutdownPage()
{
  // page
  QFrame * page = addPage(i18n("Shutdown"));

  // checkboxes
  QCheckBox * checkRecording = new QCheckBox(i18n("Warn if shutdown while recording"), page, "kcfg_WarnRecording");
  QCheckBox * checkScheduled = new QCheckBox(i18n("Warn if shutdown while scheduled recording"), page, "kcfg_WarnScheduled");
  timeselector * warnTime = new timeselector(page, i18n("during the next"), "WarnScheduledTime");
  QLabel * label = new QLabel(i18n("Wait before shutdown"), page);
  KIntNumInput * shutdownWait = new KIntNumInput(page, "kcfg_ShutdownWait");
  shutdownWait->setMinValue(0);
  shutdownWait->setMaxValue(36000);
  QLabel * unit = new QLabel(i18n("seconds"), page);

  // layout
  QGridLayout * gridWait = new QGridLayout(1, 3, 5);
  gridWait->setColStretch(2, 1);
  gridWait->addMultiCellWidget(label, 0, 0, 0, 0);
  gridWait->addMultiCellWidget(shutdownWait, 0, 0, 1, 1);
  gridWait->addMultiCellWidget(unit, 0, 0, 2, 2);

  QGridLayout * grid = new QGridLayout(page, 5, 3, 5);
  grid->setColSpacing(0, 40);
  grid->setColStretch(2, 1);
  grid->setRowStretch(4, 1);
  grid->addMultiCellWidget(checkRecording, 0, 0, 0, 2);
  grid->addMultiCellWidget(checkScheduled, 1, 1, 0, 2);
  grid->addMultiCellWidget(warnTime, 2, 2, 1, 1);
  grid->addMultiCellLayout(gridWait, 3, 3, 0, 2);


  // slots
  connect(checkScheduled, SIGNAL(toggled(bool)), warnTime, SLOT(setEnabled(bool)));

  // init
  checkRecording->setChecked(true);
  checkScheduled->setChecked(true);
}

void preferences::createSoundPage()
{
  // page
  QFrame * page = addPage(i18n("Recordings"));

  // start file
  fileselector * start = new fileselector(page, i18n("Sound when recording starts"),
                                          i18n("Sound file:"), "StartSound", false);
  fileselector * stop = new fileselector(page, i18n("Sound when recording ends"),
                                         i18n("Sound file:"), "StopSound", false);

  // grid
  QGridLayout * grid = new QGridLayout(page, 4, 3, 5);
  grid->setColSpacing(0, 40);
  grid->setColStretch(2, 1);
  grid->setRowStretch(4, 1);
  grid->addMultiCellWidget(start, 0, 0, 0, 2);
  grid->addMultiCellWidget(stop, 1, 1, 0, 2);
}

void preferences::createTrayPage()
{
  QFrame * page = addPage(i18n("Tray"));

  // checkboxes
  QCheckBox * checkTimer = new QCheckBox(i18n("Show timer"), page, "kcfg_ShowTimer");
  QCheckBox * checkToggle = new QCheckBox(i18n("Toggle status and timer"), page, "kcfg_ToggleTimer");
  KComboBox * timerMode = new KComboBox(page, "kcfg_TimerMode");
  timerMode->insertItem(i18n("Countdown to next recording"));
  timerMode->insertItem(i18n("Time of the next recording"));
  QCheckBox * checkToggleTimerIfIdle = new QCheckBox(i18n("Don't toggle timer if idle"),
                                           page, "kcfg_DontToggleIfIdle");
  QCheckBox * checkEventPopup = new QCheckBox(i18n("Show popup on events"), page, "kcfg_ShowEventPopup");
  QLabel * labelTime = new QLabel(i18n("Toggle every"), page);
  KIntNumInput * toggleTimerInterval = new KIntNumInput(page, "kcfg_ToggleTimerInterval");
  toggleTimerInterval->setMinValue(1);
  toggleTimerInterval->setMaxValue(10);
  QLabel * labelUnit = new QLabel(i18n("second(s)"), page);
  QCheckBox * checkSpace = new QCheckBox(i18n("Show disk usage"), page, "kcfg_ShowSpace");
  KComboBox * spaceMode = new KComboBox(page, "kcfg_SpaceMode");
  spaceMode->insertItem(i18n("Always"));
  spaceMode->insertItem(i18n("If not enough space"));
  spaceMode->insertItem(i18n("If space is low"));

  // grid
  QGridLayout * grid = new QGridLayout(page, 7, 5, 5);
  grid->setColSpacing(0, 40);
  grid->setColStretch(4, 1);
  grid->addMultiCellWidget(checkTimer, 0, 0, 0, 2);
  grid->addMultiCellWidget(timerMode, 0, 0, 3, 4);
  grid->addMultiCellWidget(checkToggle, 1, 1, 0, 4);
  grid->addMultiCellWidget(checkToggleTimerIfIdle, 2, 2, 0, 4);
  grid->addMultiCellWidget(checkEventPopup, 3, 3, 0, 4);
  grid->addMultiCellWidget(labelTime, 4, 4, 0, 0);
  grid->addMultiCellWidget(toggleTimerInterval, 4, 4, 1, 1);
  grid->addMultiCellWidget(labelUnit, 4, 4, 2, 4);
  grid->addMultiCellWidget(checkSpace, 5, 5, 0, 2);
  grid->addMultiCellWidget(spaceMode, 5, 5, 3, 4);

  // slots
  connect(checkTimer, SIGNAL(toggled(bool)), timerMode, SLOT(setEnabled(bool)));
  connect(checkToggle, SIGNAL(toggled(bool)), labelTime, SLOT(setEnabled(bool)));
  connect(checkToggle, SIGNAL(toggled(bool)), toggleTimerInterval, SLOT(setEnabled(bool)));
  connect(checkToggle, SIGNAL(toggled(bool)), labelUnit, SLOT(setEnabled(bool)));
  connect(checkToggle, SIGNAL(toggled(bool)), checkToggleTimerIfIdle, SLOT(setEnabled(bool)));

  // init
  checkTimer->setChecked(true);
}

void preferences::createDiskPage()
{
  QFrame * page = addPage(i18n("Space"));

  // disk check
  QCheckBox * checkSpace = new QCheckBox(i18n("Monitor free disk space"), page, "kcfg_SpaceMonitor");
  QLabel * labelSpace = new QLabel(i18n("Space per hour (MB):"), page);
  KIntNumInput * numSpace = new KIntNumInput(page, "kcfg_MBPerHour");
  numSpace->setMinValue(2000);
  numSpace->setMaxValue(20000);
  QLabel * labelLow = new QLabel(i18n("Signal low space if disk is filled more than (%):"), page);
  KIntNumInput * numLow = new KIntNumInput(page, "kcfg_LowPercentFull");
  numLow->setMinValue(1);
  numLow->setMaxValue(100);
  fileselector * noSpaceSound = new fileselector(page, i18n("Sound when not enough disk space"),
                                              i18n("Sound file:"), "NoSpaceSound", false);
  fileselector * lowSpaceSound = new fileselector(page, i18n("Sound when disk space is low"),
                                              i18n("Sound file:"), "LowSpaceSound", false);

  // grid
  QGridLayout * grid = new QGridLayout(page, 6, 3, 5);
  grid->setColStretch(2, 1);
  grid->addMultiCellWidget(checkSpace, 0, 0, 0, 2);
  grid->addMultiCellWidget(labelSpace, 1, 1, 0, 0);
  grid->addMultiCellWidget(numSpace, 1, 1, 1, 1);
  grid->addMultiCellWidget(labelLow, 2, 2, 0, 0);
  grid->addMultiCellWidget(numLow, 2, 2, 1, 1);
  grid->addMultiCellWidget(noSpaceSound, 3, 3, 0, 2);
  grid->addMultiCellWidget(lowSpaceSound, 4, 4, 0, 2);
}
