/***************************************************************************
 *   Copyright (C) 2005 by Bernd Juraschek   *
 *   vdrmon@bjusystems.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <klocale.h>
#include <qstring.h>

#include "recordings.h"

recordings::recordings()
{
}

recordings::~recordings()
{
}

void recordings::clear()
{
  // clear old recordings
  oldRecordings.setAutoDelete(true);
  oldRecordings.clear();

  // save new recordings
  oldRecordings = newRecordings;
  newRecordings.clear();
}

void recordings::add(const QString& text)
{
  newRecordings.append(new recording(text));
}

void recordings::finish()
{
  unsigned oldCount = oldRecordings.count();
  unsigned newCount = newRecordings.count();

  // check for finished recordings
  QString stopped = "";
  long stoppedCount = 0;
  for(unsigned i = 0; i < oldCount; i++)
  {
    bool changed = true;
    for(unsigned j = 0; j < newCount; j++)
    {
      if (*oldRecordings.at(i) == *newRecordings.at(j))
      {
        changed = false;
        break;
      }
    }
    if (changed)
    {
      stopped += "<li>" + oldRecordings.at(i)->getSingleLineTitle() + "</li>";
      ++stoppedCount;
    }
  }

  // check for new recordings
  QString started = "";
  long startedCount = 0;
  for(unsigned i = 0; i < newCount; i++)
  {
    bool changed = true;
    for(unsigned j = 0; j < oldCount; j++)
    {
      if (*newRecordings.at(i) == *oldRecordings.at(j))
      {
        changed = false;
        break;
      }
    }
    if (changed)
    {
      started += "<li>" + newRecordings.at(i)->toString() + "</li>";
      ++startedCount;
    }
  }

  popupText = "";
  if (started.length() > 0)
  {
    popupText = "<b>" + i18n("Started recording", "%n started recordings", startedCount) +
                  ":</b><ul>" + started + "</ul>";
  }
  if (stopped.length() > 0)
  {
    popupText += "<b>" + i18n("Finished recording", "%n finished recordings", stoppedCount) +
                  ":</b><ul>" + stopped + "</ul>";
  }
}

const QPtrList<recording>& recordings::getRecordings() const
{
  return newRecordings;
}

QString recordings::getPopupText()
{
  return popupText;
}

int recordings::getNeededSpace(int MBperHour)
{
  int count = newRecordings.count();
  int needed = 0;
  for (int i = 0; i < count; i++)
  {
    recording * rec = newRecordings.at(i);
    needed += rec->getNeededSpace(MBperHour);
  }

  return needed;
}

QString recordings::toString()
{
  QString text;
  unsigned count = newRecordings.count();
  if (count > 0)
  {
    text = "<ul>";
    for (unsigned i = 0; i < count; i++)
    {
      recording * rec = newRecordings.at(i);
      text += "<li>" + rec->toString() + "</li>";
    }
    text += "</ul>";
  }
  return text;
}

