/***************************************************************************
 *   Copyright (C) 2005 by Bernd Juraschek   *
 *   vdrmon@bjusystems.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <klocale.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qstringlist.h>
#include <klistview.h>
#include <klineedit.h>


#include "status.h"
#include "recordings.h"

status::status() : KDialogBase(Plain, i18n("VDR status monitor"), Close, Close)
{
  // get page
  QFrame * page = plainPage();

  // create widgets
  QLabel * labelStatusLabel = new QLabel(i18n("Status:"), page);
  editStatus = new KLineEdit(page);
  QLabel * labelPlayingLabel = new QLabel(i18n("Playing:"), page);
  editPlaying = new KLineEdit(page);
  QLabel * labelRecordingLabel = new QLabel(i18n("Recording:"), page);
  lvRecordings = new KListView(page);

  // properties
  editStatus->setReadOnly(true);
  editPlaying->setReadOnly(true);

  // columns
  lvRecordings->addColumn(i18n("Start"), 60);
  lvRecordings->addColumn(i18n("End"), 60);
  lvRecordings->addColumn(i18n("Title"), 250);
  lvRecordings->addColumn(i18n("Comment"), 300);

  // create layout
  QGridLayout * grid = new QGridLayout(page, 4, 2, 5);
  grid->addMultiCellWidget(labelStatusLabel, 0, 0, 0, 0);
  grid->addMultiCellWidget(editStatus, 0, 0, 1, 1);
  grid->addMultiCellWidget(labelPlayingLabel, 1, 1, 0, 0);
  grid->addMultiCellWidget(editPlaying, 1, 1, 1, 1);
  grid->addMultiCellWidget(labelRecordingLabel, 2, 2, 0, 1);
  grid->addMultiCellWidget(lvRecordings, 3, 3, 0, 1);
}


status::~status()
{
}

void status::setPlaying(const QString& title)
{
  editPlaying->setText(title);
}

void status::clearPlaying()
{
  editPlaying->setText("");
}

void status::clearStatus()
{
  editStatus->setText("");
}

void status::setStatus(const QString& text)
{
  editStatus->setText(text);
}

void status::fillRecordings(const recordings& recs)
{
  lvRecordings->clear();

  QPtrList<recording> recList = recs.getRecordings();
  unsigned count = recList.count();
  for(unsigned i = 0; i < count; i++)
  {
    recording * rec = recList.at(i);
    KListViewItem * item = new KListViewItem(lvRecordings, rec->getStart(), rec->getStop(),
                                             rec->getTitle(), rec->getComment());
    item->setMultiLinesEnabled(true);
  }
}

#include "status.moc"
