/***************************************************************************
 *   Copyright (C) 2005 by Bernd Juraschek   *
 *   kvdrmon@bjusystems.de   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <klocale.h>
#include <qtooltip.h>
#include "tooltip.h"
#include "kvdrmon.h"

tooltip::tooltip(kvdrmon * main) : space(0)
{
  this->main = main;
}


tooltip::~tooltip()
{
}

void tooltip::setStatus(bool connected)
{
  if (connected)
    status = i18n("Connected");
  else
    status = i18n("Not connected");
}

void tooltip::setPlaying(QString plays)
{
  this->plays = plays;
}

void tooltip::setRecording(recordings& recs)
{
  records = recs.toString();
}

void tooltip::setScheduled(recordings& recs)
{
  scheduled = recs.toString();
}

void tooltip::setSpace(diskspace& space)
{
  this->space = space;
}

void tooltip::update(int needed)
{
  QString newText = "<b>" + i18n("Status") + ":</b> " + status + "<br/>";
  if (!plays.isEmpty())
    newText += "<b>" + i18n("Playing") + ":</b>" + plays + "<br/>";
  if (!records.isEmpty())
    newText += "<b>" + i18n("Recording") + ":</b><br/>" + records;
  if (!scheduled.isEmpty())
    newText += "<b>" + i18n("Next scheduled") + ":</b> " + start + "<br/>" + scheduled;
  if (!stop.isEmpty())
    newText += "<b>" + i18n("Automatic shutdown") + ":</b> " + stop + "<br/>";
  newText += "<b>" + i18n("Disk usage") + ":</b> " + space.toString(needed);

  if (newText != text)
  {
    text = newText;
    QToolTip::remove(main);
    QToolTip::add(main, text);
  }
}

void tooltip::setStart(time_t start)
{
  QDateTime time;
  time.setTime_t(start);
  this->start = time.toString(i18n("yyyy-MM-dd, hh:mm"));
}

void tooltip::setShutdown(time_t stop)
{
  if (stop > 0)
  {
    QDateTime time;
    time.setTime_t(stop);
    this->stop = time.toString(i18n("yyyy-MM-dd, hh:mm"));
  }
  else
  {
    this->stop = "";
  }
}


